@@ -1,6 +1,5 @@
 package urpm::args;
 
-# $Id: args.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use warnings;
@@ -19,7 +18,7 @@ our @EXPORT = '%options';
 
 # Configuration of Getopt. urpmf is a special case, because we need to
 # parse non-alphanumerical options (-! -( -))
-my @configuration = qw(bundling gnu_compat permute);
+my @configuration = qw(bundling no_ignore_case permute);
 push @configuration, 'pass_through'
     if $tool eq 'urpmf' || $tool eq 'urpmi.addmedia';
 Getopt::Long::Configure(@configuration);
@@ -118,12 +117,20 @@ my %options_spec = (
 	justdb => \$options{justdb},
 	replacepkgs => \$options{replacepkgs},
 	suggests => sub { 
-	    $urpm->{fatal}(1, "Use --allow-suggests instead of --suggests");
+	    $urpm->{fatal}(1, "Use --allow-recommends instead of --suggests");
+	},
+	'allow-suggests' => sub {
+	    warn "WARNING: --allow-suggests is deprecated. Use --allow-recommends instead\n";
+	    $urpm->{options}{'no-recommends'} = 0 },
+	'allow-recommends' => sub { $urpm->{options}{'no-recommends'} = 0 },
+	'no-recommends' => sub { $urpm->{options}{'no-recommends'} = 1 },
+	'no-suggests' => sub { # COMPAT
+	    warn "WARNING: --no-suggests is deprecated. Use --no-recommends instead\n";
+	    $urpm->{options}{'no-recommends'} = 1;
 	},
-	'allow-suggests' => sub { $urpm->{options}{'no-suggests'} = 0 },
-	'no-suggests' => sub { $urpm->{options}{'no-suggests'} = 1 },
 	'allow-nodeps' => sub { $urpm->{options}{'allow-nodeps'} = 1 },
 	'allow-force' => sub { $urpm->{options}{'allow-force'} = 1 },
+	'downgrade' => sub { $urpm->{options}{downgrade} = 1 },
 	'parallel=s' => \$::parallel,
 
 	'metalink!' => sub { $urpm->{options}{metalink} = $_[1] },
@@ -166,6 +173,7 @@ my %options_spec = (
 	'norebuild!' => sub { $urpm->{options}{'build-hdlist-on-error'} = !$_[1] },
 	'test!' => \$::test,
 	'debug__do_not_install' => \$options{debug__do_not_install},
+	deploops => \$options{deploops},
 	'skip=s' => \$options{skip},
 	'prefer=s' => \$options{prefer},
  	'root=s' => sub { set_root($urpm, $_[1]) },
@@ -257,9 +265,13 @@ my %options_spec = (
 	provides => \$options{provides},
 	sourcerpm => \$options{sourcerpm},
 	'summary|S' => \$options{summary},
+	recommends => sub {
+	    $options{recommends} = 1;
+	},
 	suggests => sub { 
 	    $urpm->{error}("--suggests now displays the suggested packages, see --allow-suggests for previous behaviour");
-	    $options{suggests} = 1;
+	    $urpm->{error}("You should now use --recommends.");
+	    $options{recommends} = 1;
 	},
 	'list-media:s' => sub { $options{list_media} = $_[1] || 'all' },
 	'list-url' => \$options{list_url},
@@ -416,7 +428,7 @@ foreach my $k ("test!", "force", "root=s", "use-distrib=s", 'env=s',
 {
     $options_spec{urpme}{$k} = $options_spec{urpmi}{$k};
 }
-foreach my $k ("root=s", "nolock", "use-distrib=s", "skip=s", "prefer=s", "synthesis=s", 'no-suggests', 'allow-suggests', 'auto-orphans')
+foreach my $k ("root=s", "nolock", "use-distrib=s", "skip=s", "prefer=s", "synthesis=s", 'no-recommends', 'no-suggests', 'allow-recommends', 'allow-suggests', 'auto-orphans')
 {
     $options_spec{urpmq}{$k} = $options_spec{urpmi}{$k};
 }
@@ -524,7 +536,6 @@ usage:
 
 1;
 
-__END__
 
 =head1 NAME
 
@@ -542,6 +553,8 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-=cut
+Copyright (C) 2011-2017 Mageia
 
 =for vim:ts=8:sts=4:sw=4
+
+=cut
